@@ -4,11 +4,11 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.023_01';
+our $VERSION   = '0.023_02';
 
 use Scalar::Util qw< blessed >;
 
-our @EXPORT_OK = qw( CodeLike StringLike TypeTiny HashLike ArrayLike to_TypeTiny );
+our @EXPORT_OK = ( __PACKAGE__->type_names, qw/to_TypeTiny/ );
 
 my %cache;
 
@@ -37,6 +37,11 @@ sub get_type
 	return;
 }
 
+sub type_names
+{
+	qw( CodeLike StringLike TypeTiny HashLike ArrayLike );
+}
+
 sub StringLike ()
 {
 	require Type::Tiny;
@@ -317,6 +322,8 @@ works, for rough compatibility with a real L<Type::Library> type library.
 
 =item C<< get_type($name) >>
 
+=item C<< type_names >>
+
 =back
 
 =head1 BUGS
